import { defineStore } from 'pinia'
import { ref } from 'vue'
import { getRecordPage, getRecordById, startTrain, finishTrain, addTrain, delTrainByIOd } from '@/api/record'
import router from '@/router'
import { getLocation } from '@/utils/wx'

export const useTrainStore = defineStore('useTrainStore', () => {
  const list = ref([])

  // state 2 未开始 1 培训中 0 已结束
  const current = ref({
    id: ''
  })
  const recordPage = async (params) => {
    return await getRecordPage(params)
  }

  const byId = async (id) => {
    const { data } = await getRecordById(id)
    current.value = data
  }

  const start = async (id) => {
    const { latitude, longitude } = await getLocation()
    const { status } = await startTrain({
      id, latitude, longitude
    })
    if (status === 200) {
      // eslint-disable-next-line no-undef
      showToast('培训开始')
      router.push({
        path: '/training'
      })
    }
  }

  const finish = async (id) => {
    const { latitude, longitude } = await getLocation()
    const { status } = await finishTrain({
      id, latitude, longitude
    })
    if (status === 200) {
      // eslint-disable-next-line no-undef
      showToast('培训结束')
      router.push({
        path: '/trained'
      })
    }
  }

  const add = async (_data) => {
    const { status, data } = await addTrain(_data)
    if (status === 200) {
      // eslint-disable-next-line no-undef
      showToast('新增成功')
      current.value = { id: data }
    }
  }
  const del = async (id) => {
    const { status } = await delTrainByIOd(id)
    if (status === 200) {
      // eslint-disable-next-line no-undef
      showToast('删除成功')
      console.log('id: ', id, list.value)
    }
  }

  return {
    list,
    current,
    recordPage,
    byId,
    start,
    finish,
    add,
    del
  }
}, {
  persist: true
})
