import { defineStore } from 'pinia'
import { ref } from 'vue'
import { checkIn, getCheckInState, review, getReviewState, getVisitorTrainRecord, getVisitorInfo, registerLocation } from '@/api/visitor'
import { getLocation, getQueryString } from '@/utils/wx'
import router from '@/router'

export const useVisitorStore = defineStore('useVisitorStore', () => {
  const visitorTrainDetail = ref()

  const visitorInfo = ref()
  const _checkIn = async (id) => {
    const { latitude, longitude } = await getLocation()
    const params = {
      id,
      ...visitorInfo.value,
      latitude,
      longitude
    }
    const { status } = await checkIn(params)
    if (status === 200) {
      // eslint-disable-next-line no-undef
      showToast('签到成功')
    }
  }

  const checkInState = async (id) => {
    const params = {
      id,
      ...visitorInfo.value
    }
    return await getCheckInState(params)
  }

  const _review = async (data) => {
    const { latitude, longitude } = await getLocation()
    const $par = {
      ...data,
      ...visitorInfo.value,
      latitude,
      longitude
    }
    await review($par)
  }

  const reviewState = async (id) => {
    const $par = {
      id,
      ...visitorInfo.value
    }
    return await getReviewState($par)
  }

  const getVisitorTrainDetail = async (id) => {
    const { data } = await getVisitorTrainRecord(id)
    visitorTrainDetail.value = data
  }

  const _getVisitorInfo = async (code) => {
    const { data } = await getVisitorInfo(code)
    console.log('_getVisitorInfo:', data)
    visitorInfo.value = data
  }

  return {
    visitorTrainDetail,
    visitorInfo,
    checkIn: _checkIn,
    checkInState,
    reviewState,
    review: _review,
    getVisitorTrainDetail: getVisitorTrainDetail,
    getVisitorInfo: _getVisitorInfo
  }
}, {
  persist: true
})
